translate.misc.progressbar.ProgressBar

Package translate :: Package misc :: Module progressbar :: Class ProgressBar |
[hide private]
[frames] | no frames]

# Class ProgressBar

source code

A plain progress bar that doesn't know very much about output.

Instance Methods | [hide private]
__init__(self, minValue=0, maxValue=100, totalWidth=50) | source code
__str__(self) Produces the string representing the progress bar. | source code
show(self, verbosemessage) displays the progress bar | source code